==> huaweicloudsdkbms-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/os_extended_volumes.py <==
# coding: utf-8

import re
import six





class OsExtendedVolumes:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'delete_on_termination': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'delete_on_termination': 'delete_on_termination'
    }

    def __init__(self, id=None, delete_on_termination=None):
        """OsExtendedVolumes - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._delete_on_termination = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if delete_on_termination is not None:
            self.delete_on_termination = delete_on_termination

    @property
    def id(self):
        """Gets the id of this OsExtendedVolumes.

        云硬盘ID

        :return: The id of this OsExtendedVolumes.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OsExtendedVolumes.

        云硬盘ID

        :param id: The id of this OsExtendedVolumes.
        :type: str
        """
        self._id = id

    @property
    def delete_on_termination(self):
        """Gets the delete_on_termination of this OsExtendedVolumes.

        删裸金属服务器时是否一并删除该卷。true：是false：否

        :return: The delete_on_termination of this OsExtendedVolumes.
        :rtype: bool
        """
        return self._delete_on_termination

    @delete_on_termination.setter
    def delete_on_termination(self, delete_on_termination):
        """Sets the delete_on_termination of this OsExtendedVolumes.

        删裸金属服务器时是否一并删除该卷。true：是false：否

        :param delete_on_termination: The delete_on_termination of this OsExtendedVolumes.
        :type: bool
        """
        self._delete_on_termination = delete_on_termination

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OsExtendedVolumes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbms-3.0.54-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/os_extended_volumes.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class OsExtendedVolumes:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'delete_on_termination': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'delete_on_termination': 'delete_on_termination'
    }

    def __init__(self, id=None, delete_on_termination=None):
        """OsExtendedVolumes - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._delete_on_termination = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if delete_on_termination is not None:
            self.delete_on_termination = delete_on_termination

    @property
    def id(self):
        """Gets the id of this OsExtendedVolumes.

        云硬盘ID

        :return: The id of this OsExtendedVolumes.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OsExtendedVolumes.

        云硬盘ID

        :param id: The id of this OsExtendedVolumes.
        :type: str
        """
        self._id = id

    @property
    def delete_on_termination(self):
        """Gets the delete_on_termination of this OsExtendedVolumes.

        删裸金属服务器时是否一并删除该卷。true：是false：否

        :return: The delete_on_termination of this OsExtendedVolumes.
        :rtype: bool
        """
        return self._delete_on_termination

    @delete_on_termination.setter
    def delete_on_termination(self, delete_on_termination):
        """Sets the delete_on_termination of this OsExtendedVolumes.

        删裸金属服务器时是否一并删除该卷。true：是false：否

        :param delete_on_termination: The delete_on_termination of this OsExtendedVolumes.
        :type: bool
        """
        self._delete_on_termination = delete_on_termination

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OsExtendedVolumes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
